@@ -6,8 +6,9 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.0000_04'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
+use List::Util qw(reduce);
 use PDL::Core qw(ones);
 use PDL::Lite;
 use Math::LOESS::_swig;
@@ -47,10 +48,12 @@ sub new {
         unless ( $w->dim(0) == $n ) {
             die "weights if given must have same length as y";
         }
+        ($x, $y, $w) = $class->_process_bad_values($x, $y, $w);
     }
     else {
-        $w = ones($n);
+        ($x, $y) = $class->_process_bad_values($x, $y);
     }
+    $n = $y->dim(0);
 
     my $x1 = Math::LOESS::_swig::pdl_to_darray($x);
     my $y1 = Math::LOESS::_swig::pdl_to_darray($y);
@@ -149,6 +152,7 @@ sub predict {
     unless ( $newdata->dim(1) == $self->p ) {
         die "newdata's dim 1 must be same as that of x";
     }
+    ($newdata) = $self->_process_bad_values($newdata);
 
     unless ($self->activated) {
         $self->fit();
@@ -189,6 +193,20 @@ EOT
     return $s;
 }
 
+sub _process_bad_values {
+    my ( $class, $p1, @rest ) = @_;    # $p1 can be multi dimensional
+
+    if ( $p1->badflag or ( grep { $_->badflag } @rest ) ) {
+        my $p1_isbad = $p1->isbad;
+        my @p1_isbad =
+          map { $p1_isbad->slice(",($_)") } ( 0 .. $p1->dim(1) - 1 );
+        my $isbad =
+          reduce { ( $a | $b ) } ( @p1_isbad, map { $_->isbad } @rest );
+        return ( map { $_->where( !$isbad ) } ( $p1, @rest ) );
+    }
+    return ( $p1, @rest );
+}
+
 1;
 
 __END__
@@ -203,7 +221,7 @@ Math::LOESS - Perl wrapper of the Locally-Weighted Regression package originally
 
 =head1 VERSION
 
-version 0.0000_04
+version 0.0001
 
 =head1 SYNOPSIS
 
@@ -271,6 +289,8 @@ When provided as a construction parameter, it is like a shortcut for,
 
 =back
 
+Bad values in C<$x>, C<$y>, C<$weights> are removed.
+
 =head1 NAME
 
 Math::LOESS - Perl wrapper of the Locally-Weighted Regression package originally written by Cleveland, et al.
@@ -313,6 +333,8 @@ Returns a true value if the object's C<fit()> method has been called.
 
 Returns a L<Math::LOESS::Prediction> object.
 
+Bad values in C<$newdata> are removed.
+
 =head2 summary
 
     summary()
