@@ -6,7 +6,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.0000_04'; # TRIAL VERSION
+our $VERSION = '0.0001'; # VERSION
 
 use Math::LOESS::_swig;
 use Type::Params qw(compile_named);
@@ -86,7 +86,7 @@ Math::LOESS::Prediction - Math::LOESS prediction and confidence intervals
 
 =head1 VERSION
 
-version 0.0000_04
+version 0.0001
 
 =head1 DESCRIPTION
 
@@ -124,8 +124,7 @@ C<(one_delta ** 2) / two_delta>
 
 Returns the confidence intervals for predicted values, as a hashref of
 C<{ fit =E<gt> $fit, upper =E<gt> $upper, lower =E<gt> $lower }>,
-where C<$fit>, C<$upper>, C<$lower> are piddles of same length as the
-C<values> attr.
+where C<$fit>, C<$upper>, C<$lower> are piddles.
 
 =head1 SEE ALSO
 
